@@ -1,6 +1,9 @@
 ## ----include=FALSE----------------------------------------------------------------------------------------------------
 suppressPackageStartupMessages(library("lessR"))
 
+## ----include=FALSE----------------------------------------------------------------------------------------------------
+knitr::opts_chunk$set(fig.width=3.5, fig.height=3)
+
 ## ----pivot, dataTable, echo=FALSE, out.width='92%', fig.align='center', out.extra='style="border-style: none"'--------
 knitr::include_graphics(system.file("img", "pivot.png", package="lessR"))
 
@@ -42,19 +45,16 @@ d <- Read("Mach4", quiet=TRUE)
 pivot(d, c(mean,sd,skew,kurtosis), m01:m20)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-pivot(d, table, m06)
+pivot(d, table, by=m06)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-pivot(d, table, m06, m07)
+pivot(d, table, by=c(m06, m07))
 
 ## ---------------------------------------------------------------------------------------------------------------------
 Prop_test(m06, by=m07, data=d)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-pivot(d, c(mean,sd,table), m06, c(m07, m10))
-
-## ---------------------------------------------------------------------------------------------------------------------
-pivot(d, table, m06, m07, table_prop="row")
+pivot(d, c(mean,sd), m06, c(m07, m10))
 
 ## ---------------------------------------------------------------------------------------------------------------------
 d <- Read("Employee", quiet=TRUE)
@@ -80,7 +80,7 @@ pivot(d, c(mean, median), Salary, c(Gender,Dept), out_names=c("MeanSalary", "Med
 
 ## ---------------------------------------------------------------------------------------------------------------------
 a <- pivot(d, mean, Salary, c(Dept, Gender))
-sort_by(a, by=Salary_mean, direction="-")
+order_by(a, by=Salary_mean, direction="-")
 
 ## ---------------------------------------------------------------------------------------------------------------------
 #d |> pivot(mean, Salary, c(Dept, Gender)) -> a
